@@ -13,7 +13,7 @@
 #' @author Raymond McTaggart
 #' @seealso \code{\link{Quandl.auth}}
 #' @examples \dontrun{
-#' output = Quandlsearch("oil")
+#' search.results <- Quandl.search("oil")
 #' }
 #' @importFrom RJSONIO fromJSON
 #' @export
@@ -31,14 +31,9 @@ Quandl.search <- function(query, page=1, source=NULL, silent=FALSE, authcode=Qua
         params$source_code <- source
     }
     params$page <- as.character(page)
-    headers <- basicHeaderGatherer()
     path = "datasets"
-    response <- do.call(quandl.api, c(path=path, headers = headers$update, params))
-    if (is.na(authcode))
-        Quandl.limit(headers$value()[["X-RateLimit-Remaining"]])
-    if (length(grep("403", headers$value()[["status"]])))
-        stop(response)
-    json <- try(fromJSON(response),silent=TRUE)
+    json <- do.call(quandl.api, c(path=path, params))
+    # json <- try(fromJSON(response),silent=TRUE)
     if (inherits(json, 'try-error'))
         stop("No data")
     list <- list()
